//[mahjong-utils](../../../index.md)/[mahjongutils.models](../index.md)/[TileType](index.md)/[values](values.md)

# values

[common]\
fun [values](values.md)(): [Array](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-array/index.html)&lt;[TileType](index.md)&gt;

Returns an array containing the constants of this enum type, in the order they're declared.

This method may be used to iterate over the constants.
